@@ -23,12 +23,12 @@ from .base import BaseActor, Reply
 from .client import AMQPClient
 from .command import Command, TimedCommandList
 from .exceptions import CommandError
-from .parser import ClickParser, CluCommand
+from .parsers import ClickParser, CluCommand
 from .protocol import TCPStreamServer
 from .tools import log_reply
 
 
-__all__ = ["AMQPActor", "JSONActor"]
+__all__ = ["AMQPActor", "JSONActor", "AMQPBaseActor", "TCPBaseActor"]
 
 
 T = TypeVar("T")
@@ -41,7 +41,7 @@ class CustomTransportType(asyncio.Transport):
     multiline: bool
 
 
-class AMQPActor(AMQPClient, ClickParser, BaseActor):
+class AMQPBaseActor(AMQPClient, BaseActor):
     """An actor class that uses AMQP message brokering.
 
     This class differs from `~clu.legacy.actor.LegacyActor` in that it uses
@@ -50,6 +50,8 @@ class AMQPActor(AMQPClient, ClickParser, BaseActor):
     internals and protocols are different the entry points and behaviour for
     both classes should be almost identical.
 
+    This class needs to be subclassed with a command parser.
+
     See the documentation for `.AMQPActor` and `.AMQPClient` for additional
     parameter information.
 
@@ -171,8 +173,17 @@ class AMQPActor(AMQPClient, ClickParser, BaseActor):
             log_reply(self.log, reply.message_code, message_json)
 
 
-class JSONActor(ClickParser, BaseActor):
-    """A TCP actor that replies using JSON.
+class AMQPActor(ClickParser, AMQPBaseActor):
+    """An `AMQP actor <.AMQPBaseActor>` that uses a `click parser <.ClickParser>`."""
+
+    pass
+
+
+TCPBaseActor_co = TypeVar("TCPBaseActor_co", bound="TCPBaseActor")
+
+
+class TCPBaseActor(BaseActor):
+    """A TCP base actor that replies using JSON.
 
     This implementation of `.BaseActor` uses TCP as command/reply channel and
     replies to the user by sending a JSON-valid string. This makes it useful
@@ -184,6 +195,9 @@ class JSONActor(ClickParser, BaseActor):
     ``[<uid>] <command string>``, where ``<uid>`` is any integer unique
     identifier that will be used as ``command_id`` and appended to any reply.
 
+    This is a base actor that does not include a parser. It must be subclassed with
+    a concrete parser that overrides ``parse_command``.
+
     Parameters
     ----------
     name
@@ -228,10 +242,7 @@ class JSONActor(ClickParser, BaseActor):
 
         self.timed_commands = TimedCommandList(self)
 
-        # Add the multiline command
-        self.parser.add_command(multiline)
-
-    async def start(self) -> JSONActor:
+    async def start(self: TCPBaseActor_co) -> TCPBaseActor_co:
         """Starts the TCP server."""
 
         await self.server.start()
@@ -310,11 +321,6 @@ class JSONActor(ClickParser, BaseActor):
 
         return self.parse_command(command)
 
-    def send_command(self, *args, **kwargs):
-        """Not implemented for `.JSONActor`."""
-
-        raise NotImplementedError("JSONActor cannot send commands to other actors.")
-
     def write(self, *args, **kwargs):
         """Writes a message to user(s) as a JSON.
 
@@ -397,6 +403,22 @@ class JSONActor(ClickParser, BaseActor):
             log_reply(self.log, reply.message_code, message_json.strip())
 
 
+class JSONActor(ClickParser, TCPBaseActor):
+    """An implementation of `.TCPBaseActor` that uses a Click command parser."""
+
+    def __init__(self, *args, **kwargs):
+
+        super().__init__(*args, **kwargs)
+
+        # Add the multiline command
+        self.parser.add_command(multiline)
+
+    def send_command(self, *args, **kwargs):
+        """Not implemented for `.JSONActor`."""
+
+        raise NotImplementedError("JSONActor cannot send commands to other actors.")
+
+
 @click.command(cls=CluCommand)
 @click.option("--on/--off", default=True, help="Turn multiline on/off.")
 async def multiline(command: Command, on: bool):
