@@ -9,6 +9,7 @@
 from __future__ import annotations
 
 import asyncio
+import random
 
 from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
 
@@ -26,6 +27,7 @@ __all__ = [
     "TCPStreamClient",
     "open_connection",
     "TopicListener",
+    "ReconnectingTCPClientProtocol",
 ]
 
 T = TypeVar("T")
@@ -586,3 +588,74 @@ class TopicListener(object):
                 await queue.cancel(consumer_tag)
 
         await self.connection.close()
+
+
+class ReconnectingTCPClientProtocol(asyncio.Protocol):
+    """A reconnecting client modelled after Twisted ``ReconnectingClientFactory``.
+
+    Taken from https://bit.ly/3yn6MWa.
+    """
+
+    max_delay = 3600
+    initial_delay = 1.0
+    factor = 2.7182818284590451
+    jitter = 0.119626565582
+    max_retries = None
+
+    def __init__(self, *args, loop=None, **kwargs):
+        if loop is None:
+            loop = asyncio.get_event_loop()
+        self._loop = loop
+        self._args = args
+        self._kwargs = kwargs
+        self._retries = 0
+        self._delay = self.initial_delay
+        self._continue_trying = True
+        self._call_handle = None
+        self._connector = None
+
+    def connection_lost(self, exc):
+        if self._continue_trying:
+            self.retry()
+
+    def connection_failed(self, exc):
+        if self._continue_trying:
+            self.retry()
+
+    def retry(self):
+        if not self._continue_trying:
+            return
+
+        self._retries += 1
+        if self.max_retries is not None and (self._retries > self.max_retries):
+            return
+
+        self._delay = min(self._delay * self.factor, self.max_delay)
+        if self.jitter:
+            self._delay = random.normalvariate(self._delay, self._delay * self.jitter)
+        self._call_handle = self._loop.call_later(self._delay, self.connect)
+
+    def connect(self):
+        if self._connector is None:
+            self._connector = asyncio.create_task(self._connect())
+
+    async def _connect(self):
+        try:
+            await self._loop.create_connection(
+                lambda: self,
+                *self._args,
+                **self._kwargs,
+            )
+        except Exception as exc:
+            self._loop.call_soon(self.connection_failed, exc)
+        finally:
+            self._connector = None
+
+    def stop_trying(self):
+        if self._call_handle:
+            self._call_handle.cancel()
+            self._call_handle = None
+        self._continue_trying = False
+        if self._connector is not None:
+            self._connector.cancel()
+            self._connector = None
